<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Add the Edit Calendar fields needed by this module
 *
 * @param WPBS_Calendar
 *
 */
function wpbs_add_pricelabs_metabox($calendar)
{

    if (!wpbs_is_pricing_enabled()) {
        return;
    }

    // Get the settings
    $settings = get_option('wpbs_settings', array());

    if (empty($settings['payment_pricelabs_api'])) {
        return;
    }

    include 'views/view-pricelabs.php';
}
add_action('wpbs_view_edit_calendar_sidebar_after', 'wpbs_add_pricelabs_metabox', 20, 1);

/**
 * Save the Edit Calendar fields
 *
 * @param array $post_data
 *
 */
function wpbs_save_pricelabs_calendar_fields($post_data)
{

    if (empty($post_data['form_data'])) {
        return;
    }

    $form_data = $post_data['form_data'];

    if (empty($form_data['calendar_id'])) {
        return;
    }

    if (empty($form_data['wpbs_token_calendar_pricelabs']) || !wp_verify_nonce($form_data['wpbs_token_calendar_pricelabs'], 'wpbs_token_calendar_pricelabs')) {
        return;
    }

    $calendar_id = (int) $form_data['calendar_id'];

    // Update calendar user permissions meta if the value exists
    if (!empty($form_data['calendar_pricelabs_data'])) {

        $pricelabs_data = base64_decode($form_data['calendar_pricelabs_data']);

        if ($pricelabs_data === false) {
            return;
        }

        $pricelabs_data = json_decode($pricelabs_data, true);

        if (isset($pricelabs_data['id'])) {
            wpbs_update_calendar_meta($calendar_id, 'pricelabs_id', $pricelabs_data['id']);
        }

        if (isset($pricelabs_data['pms'])) {
            wpbs_update_calendar_meta($calendar_id, 'pricelabs_pms', $pricelabs_data['pms']);
        }
    } else {
        wpbs_delete_calendar_meta($calendar_id, 'pricelabs_id');
        wpbs_delete_calendar_meta($calendar_id, 'pricelabs_pms');
    }

    if (!empty($form_data['calendar_pricelabs_restrictions'])) {
        wpbs_update_calendar_meta($calendar_id, 'pricelabs_restrictions', true);
    } else {
        wpbs_delete_calendar_meta($calendar_id, 'pricelabs_restrictions');
    }
}
add_action('wpbs_save_calendar_data', 'wpbs_save_pricelabs_calendar_fields');

/**
 * Refreshes the pricelab feeds
 *
 */
function wpbs_action_refresh_pricelabs_data()
{

    // Verify for nonce
    if (empty($_GET['wpbs_token']) || !wp_verify_nonce($_GET['wpbs_token'], 'wpbs_refresh_pricelabs_data')) {
        return;
    }

    // Get the calendar
    $calendar_id = absint($_GET['calendar_id']);

    // Verify for calendar existance
    if (empty($calendar_id)) {

        wpbs_admin_notices()->register_notice('pricelabs_calendar_id_missing', '<p>' . __('Something went wrong. Could not refresh the feed.', 'wp-booking-system-pricelabs') . '</p>', 'error');
        wpbs_admin_notices()->display_notice('pricelabs_calendar_id_missing');

        return;
    }

    wpbs_pl_update_calendar_prices($calendar_id);

    // Redirect to the iCal import/export page of the Calendar with a success message
    wp_redirect(add_query_arg(array('page' => 'wpbs-calendars', 'subpage' => 'edit-calendar', 'calendar_id' => $calendar_id, 'wpbs_message' => 'pricelabs_refresh_success'), admin_url('admin.php')));
    exit;
}
add_action('wpbs_action_refresh_pricelabs_data', 'wpbs_action_refresh_pricelabs_data');

/**
 * Make the price column read-only
 * 
 */
add_filter('wpbs_calendar_editor_columns_price_atts', function ($atts, $year, $month, $day, $event, $calendar) {

    $pricelabs_id = wpbs_get_calendar_meta($calendar->get('id'), 'pricelabs_id', true);

    if (empty($pricelabs_id)) {
        return $atts;
    }

    return 'readonly';
}, 10, 6);
