<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

class WPBS_PriceLabs_API
{

    /**
     * @param string $api_key
     *
     */
    public $api_key;

    /**
     * @param string $base_url
     *
     */
    public $base_url = 'https://api.pricelabs.co/v1/';

    public function __construct()
    {

        // Get the settings
        $settings = get_option('wpbs_settings', array());

        // Set API key
        $this->api_key = $settings['payment_pricelabs_api'];

    }

    public function get_listing_price($listing_id, $pms){
        $response = $this->post('/listing_prices', ['listings' => [['id' => $listing_id, 'pms' => $pms]]]);
        
        if(!is_array($response)){
            return [];
        }

        if(isset($response[0])){
            return $response[0];
        }
        return $response;
    }

    public function get_listings()
    {
        return $this->get('/listings');
    }

    public function validate_api_key(){
        $test = $this->get_listings();
        
        return isset($test->error) ? $test->error : true;
    }

    private function get($endpoint)
    {

        if(empty($this->api_key)){
            return (object) ['error' => 'on_api_key'];
        }

        $url = $this->base_url . trim($endpoint, '/');
        $args = array(
            'headers' => array(
                'X-Api-Key' => $this->api_key,
            ),
        );

        $response = wp_remote_get($url, $args);

        if(is_wp_error($response)){
            return (object) ['error' => $response->get_error_message()];
        }

        if (wp_remote_retrieve_response_code($response) != 200) {
            
            $body = isset($response['body']) ? $response['body'] : false;
            $body_json = json_decode($body, true);
            $body = (isset($body_json['error'])) ? $body_json['error'] : $body;
            $body = (isset($body['code'])) ? $body['code'] . ': ' . $body['message']  : $body;
            
            return (object) ['error' => wp_remote_retrieve_response_code($response) . ($body ? : '')];
        }

        return json_decode(wp_remote_retrieve_body($response));

    }

    private function post($endpoint, $body)
    {

        if(empty($this->api_key)){
            return (object) ['error' => 'on_api_key'];
        }

        $url = $this->base_url . trim($endpoint, '/');
        $args = array(
            'body' => json_encode($body),
            'headers' => array(
                'X-Api-Key' => $this->api_key,
                'Content-Type' => 'application/json',
            ),
        );

        $response = wp_remote_post($url, $args);

        if (wp_remote_retrieve_response_code($response) != 200) {
            return (object) ['error' => wp_remote_retrieve_response_code($response)];
        }

        return json_decode(wp_remote_retrieve_body($response));

    }

}
